@@ -120,7 +120,7 @@ def _safe_load_json_list(field, log_error=False):
         return []
 
 
-class FileUpload(object):
+class FileUpload:
     """
     A layer of abstraction over the various components of file
     data stored as ORA XBlock user-scoped fields.
@@ -152,6 +152,10 @@ class FileUpload(object):
 
     @property
     def download_url(self):
+        """
+        Returns the url at which the file that corresponds to the key
+        can be downloaded if exists.
+        """
         if self.exists:
             try:
                 return get_download_url(self.key)
@@ -161,6 +165,7 @@ class FileUpload(object):
                     error=exc
                 ))
                 return ''
+        return None
 
     @property
     def key(self):
@@ -201,7 +206,7 @@ FileDescriptor = namedtuple('FileDescriptor', ['download_url', 'description', 'n
 TeamFileDescriptor = namedtuple('TeamFileDescriptor', ['download_url', 'description', 'name', 'uploaded_by'])
 
 
-class FileUploadManager(object):
+class FileUploadManager:
     """
     Manages the CRUD operations of file uploads
     that take place in the context of an OpenAssessmentBlock.
@@ -309,7 +314,7 @@ class FileUploadManager(object):
         descriptors = []
 
         for upload in self.get_uploads(include_deleted=include_deleted):
-            show_delete_button = True if upload.exists else False
+            show_delete_button = bool(upload.exists)
 
             if upload.exists and self.block.is_team_assignment():
                 shared_upload = self.shared_uploads_for_team_by_key[upload.key]
