@@ -8,13 +8,13 @@ import copy
 from django.utils.translation import ugettext as _
 
 from lazy import lazy
-from openassessment.assessment.errors import PeerAssessmentError, SelfAssessmentError
 from xblock.core import XBlock
+from openassessment.assessment.errors import PeerAssessmentError, SelfAssessmentError
 
 from .data_conversion import create_submission_dict
 
 
-class GradeMixin(object):
+class GradeMixin:
     """Grade Mixin introduces all handlers for displaying grades
 
     Abstracts all functionality and handlers associated with Grades.
