@@ -7,12 +7,12 @@ from __future__ import absolute_import
 
 import logging
 
+from webob import Response
+from xblock.core import XBlock
 from openassessment.assessment.errors import (PeerAssessmentInternalError, PeerAssessmentRequestError,
                                               PeerAssessmentWorkflowError)
 from openassessment.workflow.errors import AssessmentWorkflowError
 from openassessment.xblock.defaults import DEFAULT_RUBRIC_FEEDBACK_TEXT
-from webob import Response
-from xblock.core import XBlock
 
 from .data_conversion import (clean_criterion_feedback, create_rubric_dict, create_submission_dict,
                               verify_assessment_parameters)
@@ -22,7 +22,7 @@ from .user_data import get_user_preferences
 logger = logging.getLogger(__name__)  # pylint: disable=invalid-name
 
 
-class PeerAssessmentMixin(object):
+class PeerAssessmentMixin:
     """The Peer Assessment Mixin for all Peer Functionality.
 
     Abstracts all functionality and handlers associated with Peer Assessment.
