@@ -5,13 +5,15 @@ determine the flow of the problem.
 from __future__ import absolute_import
 
 import copy
+from django.core.exceptions import ObjectDoesNotExist
 from functools import wraps
 import logging
 
 from openassessment.assessment.errors import PeerAssessmentInternalError
 from openassessment.workflow.errors import AssessmentWorkflowError, AssessmentWorkflowInternalError
-from openassessment.xblock.data_conversion import create_submission_dict
+from openassessment.xblock.data_conversion import create_submission_dict, list_to_conversational_format
 from openassessment.xblock.resolve_dates import DISTANT_FUTURE, DISTANT_PAST
+from submissions.errors import SubmissionNotFoundError, TeamSubmissionNotFoundError
 from xblock.core import XBlock
 
 from .user_data import get_user_preferences
@@ -77,7 +79,7 @@ def require_course_staff(error_key, with_json_handler=False):
     return _decorator
 
 
-class StaffAreaMixin(object):
+class StaffAreaMixin:
     """
     Display debug information to course and global staff.
     """
@@ -123,7 +125,8 @@ class StaffAreaMixin(object):
         for step in ['submission'] + self.assessment_steps:
 
             # Get the dates as a student would see them
-            __, __, start_date, due_date = self.is_closed(step=step, course_staff=False)
+            __, __, start_date, due_date = self.is_closed(
+                step=step, course_staff=False)  # pylint: disable=redeclared-assigned-name
 
             context['step_dates'].append({
                 'step': step,
@@ -139,6 +142,9 @@ class StaffAreaMixin(object):
                 self.get_staff_assessment_statistics_context(student_item["course_id"], student_item["item_id"])
             )
 
+        # Include whether or not this is a team assignment
+        context['is_team_assignment'] = self.is_team_assignment()
+
         context['xblock_id'] = self.get_xblock_id()
         return path, context
 
@@ -211,6 +217,27 @@ class StaffAreaMixin(object):
                     submission_context = self.get_student_submission_context(
                         self.get_username(anonymous_student_id), submission
                     )
+                    # Add team info to context
+                    submission_context['teams_enabled'] = self.teams_enabled
+                    if self.teams_enabled:
+                        user = self.get_real_user(anonymous_student_id)
+
+                        if not user:
+                            logger.error(
+                                '{}: User lookuip for anonymous_user_id {} failed'.format(
+                                    self.location,
+                                    anonymous_student_id
+                                )
+                            )
+                            raise ObjectDoesNotExist()
+
+                        team = self.teams_service.get_team(user, self.course_id, self.selected_teamset_id)
+
+                        submission_context['team_name'] = team.name
+                        submission_context['team_usernames'] = list_to_conversational_format(
+                            [user.username for user in team.users.all()]
+                        )
+
                     path = 'openassessmentblock/staff_area/oa_staff_grade_learners_assessment.html'
                     return self.render_assessment(path, submission_context)
                 return self.render_error(self._(u"Error loading the checked out learner response."))
@@ -261,6 +288,7 @@ class StaffAreaMixin(object):
             'user_timezone': user_preferences['user_timezone'],
             'user_language': user_preferences['user_language'],
             "prompts_type": self.prompts_type,
+            "is_team_assignment": self.is_team_assignment(),
         }
 
         if submission:
@@ -329,6 +357,15 @@ class StaffAreaMixin(object):
         if submission_uuid:
             self.add_submission_context(submission_uuid, context)
 
+        # Add team info to context
+        context['team_name'] = None
+        if anonymous_user_id and self.is_team_assignment():
+            try:
+                context['team_name'] = getattr(self.get_team_for_anonymous_user(anonymous_user_id), 'name', None)
+            except ObjectDoesNotExist:
+                # A student outside of the course will not exist and is valid
+                pass
+
         path = 'openassessmentblock/staff_area/oa_student_info.html'
         return path, context
 
@@ -416,6 +453,11 @@ class StaffAreaMixin(object):
         for a given problem. It will cancel the workflow using traditional methods to remove it from the grading pools,
         and pass through to the submissions API to orphan the submission so that the user can create a new one.
         """
+
+        if self.is_team_assignment():
+            self.clear_team_state(user_id, course_id, item_id, requesting_user_id)
+            return
+
         # Import is placed here to avoid model import at project startup.
         from submissions import api as submission_api
         # Note that student_item cannot be constructed using get_student_item_dict, since we're in a staff context
@@ -438,7 +480,47 @@ class StaffAreaMixin(object):
                 item_id,
                 clear_state=True
             )
-            # TODO: try to remove the above pylint disable once edx-submissions release is done
+
+    def clear_team_state(self, user_id, course_id, item_id, requesting_user_id):
+        """
+        This is called from clear_student_state (which is called from the LMS runtime) when the xblock is a team
+        assignment, to clear student state for an entire team for a given problem. It will cancel the workflow
+        to remove it from the grading pools, and pass through to the submissions team API to orphan the team
+        submission and individual submissions so that the team can create a new submission.
+        """
+        error_msg_base = 'Attempted to clear team state for anonymous user {} '.format(user_id)
+        try:
+            user_team = self.get_team_for_anonymous_user(user_id)
+        except ObjectDoesNotExist:
+            warning_msg = error_msg_base + 'but was unable to resolve to a real user'
+            logger.warning(warning_msg)
+            return
+
+        if user_team is None:
+            warning_msg = error_msg_base + 'but they are not on a team for course {} item {}.'.format(
+                course_id, item_id
+            )
+            logger.warning(warning_msg)
+            return
+
+        from submissions import team_api as team_submissions_api
+
+        try:
+            team_submission = team_submissions_api.get_team_submission_for_team(course_id, item_id, user_team.team_id)
+        except TeamSubmissionNotFoundError:
+            warning_msg = error_msg_base + "course {} item {} but no team submission was found for team {}".format(
+                course_id, item_id, user_team.team_id
+            )
+            logger.warning(warning_msg)
+
+        # Remove the submission from grading pool
+        self._cancel_team_workflow(
+            team_submission['team_submission_uuid'],
+            "Student and team state cleared",
+            requesting_user_id
+        )
+        # Tell the submissions API to orphan the submissions to prevent them from being accessed
+        team_submissions_api.reset_scores(team_submission['team_submission_uuid'])
 
     @XBlock.json_handler
     @require_course_staff("STUDENT_INFO", with_json_handler=True)
@@ -465,7 +547,30 @@ class StaffAreaMixin(object):
         if not comments:
             return {"success": False, "msg": self._(u'Please enter valid reason to remove the submission.')}
 
-        return self._cancel_workflow(submission_uuid, comments)
+        if self.is_team_assignment():
+            return self._cancel_team_submission(submission_uuid, comments)
+        else:
+            return self._cancel_workflow(submission_uuid, comments)
+
+    def _cancel_team_submission(self, submission_uuid, comments):
+        """
+        Cancels a team submission given an individual submission's uuid
+        """
+        not_found_msg = self._('Submission not found')
+        # Look up serialized individual submission to get team_submission_uuid
+        try:
+            submission = self.get_user_submission(submission_uuid)
+        except SubmissionNotFoundError:
+            return {"success": False, "msg": not_found_msg}
+        if not submission:
+            return {"success": False, "msg": not_found_msg}
+
+        team_submission_uuid = submission.get('team_submission_uuid', None)
+        if not team_submission_uuid:
+            msg = self._('Submission for team assignment has no associated team submission')
+            return {"success": False, "msg": msg}
+
+        return self._cancel_team_workflow(str(team_submission_uuid), comments)
 
     def _cancel_workflow(self, submission_uuid, comments, requesting_user_id=None):
         """
@@ -502,3 +607,38 @@ class StaffAreaMixin(object):
             msg = str(ex)
             logger.exception(msg)
             return {"success": False, 'msg': msg}
+
+    def _cancel_team_workflow(self, team_submission_uuid, comments, requesting_user_id=None):
+        """
+        Internal helper method to cancel a team workflow using the team workflow API.
+
+        If requesting_user is not provided, we will use the user to which this xblock is currently bound.
+        """
+        # Import is placed here to avoid model import at project startup.
+        from openassessment.workflow import team_api as team_workflow_api
+        try:
+            if requesting_user_id is None:
+                # The student_id is actually the bound user, which is the staff user in this context.
+                requesting_user_id = self.get_student_item_dict()["student_id"]
+            # Cancel the related workflow.
+            team_workflow_api.cancel_workflow(
+                team_submission_uuid,
+                comments,
+                requesting_user_id,
+            )
+            return {
+                "success": True,
+                'msg': self._(
+                    "The team’s submission has been removed from grading. "
+                    "The team receives a grade of zero unless you delete "
+                    "a team member’s state for the problem to allow the team "
+                    "to resubmit a response."
+                )
+            }
+        except (
+                AssessmentWorkflowError,
+                AssessmentWorkflowInternalError
+        ) as ex:
+            msg = str(ex)
+            logger.exception(msg)
+            return {"success": False, 'msg': msg}
