@@ -5,10 +5,10 @@ from __future__ import absolute_import
 
 import logging
 
+from xblock.core import XBlock
 from openassessment.assessment.api import staff as staff_api
 from openassessment.assessment.errors import StaffAssessmentInternalError, StaffAssessmentRequestError
 from openassessment.workflow import api as workflow_api
-from xblock.core import XBlock
 
 from .data_conversion import clean_criterion_feedback, create_rubric_dict, verify_assessment_parameters
 from .staff_area_mixin import require_course_staff
@@ -16,7 +16,7 @@ from .staff_area_mixin import require_course_staff
 logger = logging.getLogger(__name__)  # pylint: disable=invalid-name
 
 
-class StaffAssessmentMixin(object):
+class StaffAssessmentMixin:
     """
     This mixin is for all staff-assessment related endpoints.
     """
