@@ -4,12 +4,13 @@ Handle OpenAssessment XBlock requests to the Workflow API.
 
 from __future__ import absolute_import
 
+from xblock.core import XBlock
+from submissions.api import get_submissions, SubmissionInternalError, SubmissionNotFoundError
 from openassessment.workflow import api as workflow_api
 from openassessment.workflow.models import AssessmentWorkflowCancellation
-from xblock.core import XBlock
 
 
-class WorkflowMixin(object):
+class WorkflowMixin:
     """
     Handle OpenAssessment XBlock requests to the Workflow API.
     """
@@ -125,6 +126,9 @@ class WorkflowMixin(object):
         Raises:
             AssessmentWorkflowError
         """
+        if self.is_team_assignment():
+            return self.get_team_workflow_info()
+
         if submission_uuid is None:
             submission_uuid = self.get_submission_uuid()
 
@@ -148,7 +152,15 @@ class WorkflowMixin(object):
         """
         if self.submission_uuid is not None:
             return self.submission_uuid
-
+        elif self.is_team_assignment():
+            try:
+                # Query for submissions by the student item
+                student_item = self.get_student_item_dict()
+                submission_list = get_submissions(student_item)
+                if submission_list and submission_list[0]["uuid"] is not None:
+                    return submission_list[0]["uuid"]
+            except (SubmissionInternalError, SubmissionNotFoundError):
+                return None
         return None
 
     def get_workflow_status_counts(self):
